#
# spec file for package fwupd
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%ifarch %{ix86} x86_64 aarch64
%bcond_without efi_fw_update
%else
%bcond_with efi_fw_update
%endif
%if 0%{?is_opensuse}
%global efidir opensuse
%else
%global efidir sles
%endif
Name:           fwupd
Version:        1.2.3
Release:        2.1
Summary:        Device firmware updater daemon
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Management
URL:            https://fwupd.org/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  dejavu-fonts
BuildRequires:  docbook-utils-minimal
BuildRequires:  gcab
# for certtool
BuildRequires:  gnutls
BuildRequires:  gobject-introspection
BuildRequires:  gobject-introspection-devel
BuildRequires:  gpgme-devel
BuildRequires:  help2man
BuildRequires:  intltool
BuildRequires:  libelf-devel
BuildRequires:  meson >= 0.47.0
BuildRequires:  pkgconfig
BuildRequires:  procps
BuildRequires:  python3-Pillow
BuildRequires:  python3-cairo
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-xml
BuildRequires:  vala
BuildRequires:  pkgconfig(appstream-glib) >= 0.5.10
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(colorhug) >= 1.2.12
BuildRequires:  pkgconfig(gio-2.0) >= 2.25.9
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.45.8
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk-doc) >= 1.14
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(gusb) >= 0.2.9
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.1.1
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libgcab-1.0)
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.51.92
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.103
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(valgrind)
BuildRequires:  pkgconfig(xmlb)
%if %{with efi_fw_update}
BuildRequires:  gnu-efi
BuildRequires:  pesign-obs-integration
BuildRequires:  pkgconfig(efiboot)
BuildRequires:  pkgconfig(efivar) >= 33
%endif
%ifarch %{ix86} x86_64
BuildRequires:  pkgconfig(libsmbios_c) >= 2.3.0
%endif
%if %{with efi_fw_update}
%ifarch x86_64
Requires:       shim >= 11
%endif
Obsoletes:      fwupdate
%endif

%description
fwupd is a daemon to allows session software to update device firmware on
the local machine.

You can either use a GUI software manager like GNOME Software to view and apply
updates, the command line tool or the system D-Bus interface directly.

%package -n libfwupd2
Summary:        Allow session software to update device firmware
Group:          System/Libraries
Requires:       %{name} >= %{version}

%description -n libfwupd2
fwupd is a daemon to allows session software to update device firmware on
the local machine.

%package -n typelib-1_0-Fwupd-2_0
Summary:        GObject-introspection bindings for libfwupd
Group:          System/Libraries

%description -n typelib-1_0-Fwupd-2_0
fwupd is a daemon to allows session software to update device firmware on
the local machine.

%package -n dfu-tool
Summary:        Generic tool Device Firmware Upgrade (DFU) tool
Group:          Development/Tools/Other

%description -n dfu-tool
A generic tool to upload firmware to USB Devices based on Device Firmware Upgrade (DFU).

%package devel
Summary:        Allow session software to update device firmware
Group:          Development/Languages/C and C++
Requires:       libfwupd2 = %{version}

%description devel
fwupd is a daemon to allows session software to update device firmware on
the local machine.

%lang_package

%prep
%setup -q
for file in $(grep -l %{_bindir}/env . -r); do
  sed -i "s|%{_bindir}/env python3|%{_bindir}/python3|" $file
done

%build
# Dell support requires direct SMBIOS access,
# Synaptics requires Dell support, i.e. x86 only
%meson \
%if %{without efi_fw_update}
  -Dplugin_nvme=false \
  -Dplugin_redfish=false \
  -Dplugin_uefi=false \
%endif
%ifnarch %{ix86} x86_64
  -Dplugin_dell=false \
  -Dplugin_synaptics=false \
%endif
  -Dtests=false
%meson_build

%install
export BRP_PESIGN_FILES='%{_libexecdir}/fwupd/efi/fwupd*.efi'
%meson_install
# README.md is packaged as doc
rm %{buildroot}%{_localstatedir}/lib/fwupd/builder/README.md
# Add SUSE specific rcfoo service symlink
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcfwupd-offline-update
%find_lang %{name}

# do not package tests
rm -fr %{buildroot}%{_datadir}/installed-tests

%post   -n libfwupd2 -p /sbin/ldconfig
%postun -n libfwupd2 -p /sbin/ldconfig
%preun
%service_del_preun %{name}.service fwupd-offline-update.service

%pre
%service_add_pre %{name}.service fwupd-offline-update.service

%post
%udev_rules_update
%service_add_post %{name}.service fwupd-offline-update.service
%if %{with efi_fw_update}
if [ -d "/boot/efi/EFI/%{efidir}" ]; then
	# Create the directory for firwmare update capsules
	mkdir -p /boot/efi/EFI/%{efidir}/fw
	# Install the UEFI firmware update program
	cp %{_libexecdir}/fwupd/efi/fwupd*.efi /boot/efi/EFI/%{efidir}
fi
%endif

%postun
%service_del_postun %{name}.service fwupd-offline-update.service
%if %{with efi_fw_update}
if [ "$1" = 0 ] && [ -d "/boot/efi/EFI/%{efidir}" ] ; then
	# Remove all capsule files
	rm -rf /boot/efi/EFI/%{efidir}/fw
	# Remove the UEFI firmware update program
	rm -f /boot/efi/EFI/%{efidir}/fwupd*.efi
fi
%endif

%files
%license COPYING
%doc README.md
%{_libexecdir}/systemd/system/fwupd.service
%{_libexecdir}/systemd/system/fwupd-offline-update.service
%%dir %{_libexecdir}/systemd/system/system-update.target.wants/
%{_libexecdir}/systemd/system/system-update.target.wants/fwupd-offline-update.service
%{_libexecdir}/fwupd
%{_bindir}/fwupdmgr
%{_sbindir}/rc%{name}
%{_sbindir}/rcfwupd-offline-update
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.fwupd.conf
%{_datadir}/dbus-1/interfaces/org.freedesktop.fwupd.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.fwupd.service
%{_datadir}/%{name}/
%{_mandir}/man1/fwupdmgr.1%{?ext_man}
%{_datadir}/polkit-1/actions/org.freedesktop.fwupd.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.fwupd.rules
%config %{_sysconfdir}/%{name}/
%dir %{_sysconfdir}/pki
%dir %{_sysconfdir}/pki/fwupd
%dir %{_sysconfdir}/pki/fwupd-metadata
%{_sysconfdir}/pki/fwupd-metadata/GPG-KEY-Linux-Vendor-Firmware-Service
%{_sysconfdir}/pki/fwupd-metadata/GPG-KEY-Linux-Foundation-Metadata
%{_sysconfdir}/pki/fwupd-metadata/LVFS-CA.pem
%{_sysconfdir}/pki/fwupd/GPG-KEY-Hughski-Limited
%{_sysconfdir}/pki/fwupd/GPG-KEY-Linux-Vendor-Firmware-Service
%{_sysconfdir}/pki/fwupd/GPG-KEY-Linux-Foundation-Firmware
%{_sysconfdir}/pki/fwupd/LVFS-CA.pem
%{_udevrulesdir}/90-fwupd-devices.rules
%{_libdir}/fwupd-plugins-3/
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.freedesktop.fwupd.metainfo.xml
%dir %{_localstatedir}/lib/%{name}/
%{_datadir}/bash-completion/completions/fwupdmgr
%{_datadir}/bash-completion/completions/fwupdtool

%files -n dfu-tool
%{_bindir}/dfu-tool
%{_mandir}/man1/dfu-tool.1%{?ext_man}

%files -n libfwupd2
%{_libdir}/libfwupd.so.*

%files -n typelib-1_0-Fwupd-2_0
%{_libdir}/girepository-1.0/Fwupd-2.0.typelib

%files lang -f %{name}.lang
%if %{with efi_fw_update}
%{_datadir}/locale/*/LC_IMAGES/
%endif

%files devel
%doc %{_datadir}/gtk-doc/html/libfwupd/
%{_datadir}/gir-1.0/Fwupd-2.0.gir
%{_datadir}/vala/vapi/fwupd.deps
%{_datadir}/vala/vapi/fwupd.vapi
%{_includedir}/fwupd-1/
%{_libdir}/pkgconfig/fwupd.pc
%{_libdir}/libfwupd.so

%changelog
* Tue Feb  5 2019 Bernhard Voelker <mail@bernhard-voelker.de>
- fwupd.spec: fix shell syntax error in %%postun section (boo#1120363).
* Thu Jan 10 2019 bjorn.lie@gmail.com
- Update to version 1.2.3:
  * Correctly migrate the history database
  * trivial: Add some debugging data to wacom-usb
- Changes from version 1.2.2:
  * Log an error if started with an incompatible locale
  * Fix building with -Wl,-z,defs
  * ebitdo: Fix the reported version number if the daemon locale is
    not C.UTF-8
  * Add Dell TB18DC to the known devices list
  * trivial: Don't show 'Update Duration: 49710 days'
  * Allow replacing the last byte in the image when using 'dfu-tool
    replace-data'
  * trivial: Fix an error code if a search string is unfound
  * trivial: Fix a memory leak if dfu-tool returns with an error
  * trivial: Check the GUID length before attempting to parse it
  * Check the device checksum as well as the content checksum
    during verify
  * Submit the device firmware checksum and update protocol in the
    submitted report
  * trivial: Don't invalidate the current checksums for fw that
    requries a reboot
  * trivial: Clear the device checksums only if the plugin
    implements verify()
  * Include the device checksum and update protocol in the
    historydb
  * uefi: Add the PCR0 value as the device checksum for system
    firmware
  * Add new API to get the release protocol from the metadata
  * Allow plugins to define support for a 'well-known' protocol
  * uefi: When adding headers set the header size to 4k
  * uefi: Append the header on capsules without headers from Linux
  * trivial: uefi: correct a logic error in setting variable
  * trivial: dell-dock: Correct variable for turning off HDCP 2.2
  * flashrom: Ensure the quirks database is set on the new object
  * uefi: Do not add devices with invalid GUIDs
  * Do not allow a GUID of zero
  * Add shared functionality for reading and writing with
    O_NONBLOCK
  * Only run attach and detach if the device is in the wrong mode
  * trivial: snap: move to efivar 37
  * trivial: Add fu_common_dump_raw()
  * Sanitize the version if the version format has been specified
  * wacom-usb: Remove the DTH generation hardware as it will not
    work with fwupd
  * trivial: Add a snap badge for fwupd
  * trivial: dell-dock: reverse MST update order for I2C
  * thunderbolt: Remove a superfluous boundary condition when
    verifying update
  * Add a plugin to update hardware that supports fastboot
  * trivial: Speed up daemon startup
  * Fix a regression when doing GetReleases on unsupported hardware
  * trivial: Document the expected plugin firmware formats
  * dfu: Require a specific USB class and subclass for DFU mode
  * Correctly parse format the version numbers correctly using old
    metadata
  * trivial: Correctly calculate the erase length for all locales
  * amt: Fix a crash if AMT returns an empty response
  * Check plugins set error on failure
  * contrib: Add a simple python3 client
  * trivial: Allow loading archives ignoring the path
  * installed-tests: Adjust to actually use a remote for installed
    tests
  * Add more standard USB identifier GUIDs
  * wacomhid: Rename to wacom-usb
  * trivial: Allow calling fu_device_has_guid() with non-GUID text
  * trivial: Don't ask translators to translate the release notes
  * trivial: Update two release note typos
  * Provide a way for plugins to decompress a custom archive to ram
- Changes from version 1.2.1:
  * trivial: dell-dock: Set EC version to daemon before EC reset
  * trivial: dell-dock: fail when EC indicates flashing an
    invalid/unsigned image
  * trivial: Fix regression when switching to indexed strings
  * Remove DaemonVersionFormat=quad
  * Shut down the daemon after 2h of inactivity
  * Create a silo index to speed up GUID queries
  * trivial: Move the release descriptions to the metainfo.xml file
  * Fix flashing the 8bitdo SF30
  * trivial: Do a single query when getting a component by a set of
    GUIDs
  * trivial: Add InstallDuration values for 8bitdo devices
  * trivial: Add InstallDuration values for Unifying devices
  * trivial: Add InstallDuration values for ColorHug devices
  * Speed up fwupd startup by loading less thunderbolt firmware
  * trivial: Fix some function prefixes for Thunderbolt
  * trivial: Do not show all the HWIDs at daemon startup
  * Query the XbSilo when calling fu_plugin_check_supported()
  * trivial: Remove unused functionality
  * trivial: Mark GParamSpec values as static to reduce RSS
  * Guess the version format when it is not provided
  * Fix a use-after-free when using valgrind and --immediate-exit
  * trivial: Add quirk documentation
  * Add per-release install duration values
  * trivial: Create an empty tree before tests start
  * trivial: Fix a possible critical warning when parsing invalid
    metadata
  * Fix showing the custom remote agreements
  * trivial: Only include a single language in the metainfo silo
  * Be more explicit setting the update state
  * Include the os-release information in the release metadata
  * trivial: Store the AppStream component metadata correctly
  * trivial: ci: fix flatpak build
  * trivial: Drop the libxmlb insertion into the flathub manifest
  * trivial: Relax the timing requirements on the FuDevice poll
    test
  * trivial: Document the GUID generation scheme
  * trivial: Sync example spec file with downstream
  * trivial: Bump meson dependency to 0.47.0
  * trivial: post release version bump
- Changes from version 1.2.0:
  * trivial: Fix some NULL/FALSE confusion
  * trivial: Fix a typo in the verification store export
  * ebitdo: remove SF30/SN30 pro device ids
  * dell-dock: Drop delayed MST callback routine
  * trivial: Fix some NULL/FALSE confusion
  * synapticsmst: Adjust EVB board handling
  * synapticsmst: Remove the content checking of firmware
  * synapticsmst: Access Board ID through memory instead In
    firmware images HDCP 2.2 will be enabled by default,so access
    to flash region will fail.
  * trivial: fu-tool: Try to stop systemd even if not compiled with
    systemd
  * trivial: fu-tool: use `g_variant_unref` instead of
    `g_object_clear`
  * contrib: Adjust flatpak build for moving to flathub
  * dell-dock: Prefer to flash VMM5331 via I2C instead of DP aux
  * trivial: fu-engine: Increase the priority on a device if it has
    children
  * trivial: fu-device-list: Return devices by priority
  * Use HTTPS_PROXY if set
  * firmware-packager: Make it clearer to use
  * Sort the firmware sack by component priority
  * flatpak: Update gnu-efi to latest version
  * trivial: dell-dock: Lower MST communication speed to 400 KHz
  * trivial: debian: Make control file statement more generic
  * trivial: snap: Use libxmlb subproject instead
  * amt: Set the full device version including the BuildNum
  * fwupdmgr/fwupdtool: Move monitor command to fwupdtool
  * fwupdmgr/fwupdtool: Move firmware builder from fwupdmgr to
    fwupdtool
  * trivial: Add VersionFormat to the fu_device_to_string() output
  * Add version format quirks for several Lenovo machines
  * uefi: Set the quirks on created devices
  * trivial: Add yet another version encoding
  * dell_dock: Use correct offset for finding version of MST
  * dell-dock: Add missing unlock call for MST via dell_dock plugin
  * Support the Intel ME version format
  * Port from libappstream-glib to libxmlb
  * trivial: Rename a function to better explain what it does
  * Bump requirement to meson 0.46.0
  * fu-main: Catch SIGTERM while update is in progress
  * fu-tool: Stop any running daemon over dbus before loading
    engine
  * meson: Bump dependency to 0.44 and adjust sysconfdir handling
  * dell-dock: If marketing name is invalid don't fail
    initialization
  * Readme Updated: Added KDE Discover as one more graphical
    front-end available for fwupd.
  * dell-dock: Correct a situation that error wasn't propagating
  * trivial: snap: drop the stable symlink
  * trivial: snap: Swap the type of snap/snapcraft.yaml to be a
    real file
  * trivial: bump master to 1.2.0
  * Don't segfault if a plugin returns FALSE from UpdateFunc with
    no error set
  * dell-dock: Use different debug strings for each device type
  * trivial: Remove some pretty intense debugging that crept in
  * dell-dock: Don't use the VLA feature in the new dock
  * trivial: Do not allow VLA features in plugins
  * Add a plugin for an upcoming Dell USB-C dock
  * contrib: Add information on how to use debugging scripts
  * trivial: Hardcode the AppStream-glib version
  * trivial: Don't care so much about the AppStream-glib version
  * Allow setting the version format from a quirk entry
  * Don't use AppStream-glib for string helpers
  * Don't use AppStream-glib for version helpers
  * Don't use AppStream-glib for the GUID helpers
  * trivial: Don't use AppStream-glib in libfwupd
  * trivial: Remove unused header
  * fu-device: Ensure that parent ID is created before creating
    quirked children
  * trivial: libfwupd: correct documentation for
    fwupd_device_set_install_duration
  * trivial: correct a memory leak of the FuDevice when replugging
  * Update all sub-devices for a composite update
  * Stop showing the current release during updates in fwupdmgr
  * uefi: Move the TPM unlocking functionality from the Dell to
    UEFI plugin
  * Run the Dell plugin initialization after the UEFI plugin
  * trivial: Add ESP path into fu_uefi_device_to_string()
  * thunderbolt-power: Fix possible linker problem
  * trivial: Sync the flatpak manifest with the one from flathub
  * trivial: Be more explicit when building the snap packages
  * trivial: Include libuuid specifically on Centos
  * trivial: Be more explicit when building on Centos
  * trivial: Be more explicit when building the Arch package
  * trivial: nvme: Allow quirking the NVME write block size
  * Allow firmware files to depend on versions from other devices
  * trivial: fu-engine: downgrade couldn't find new device message
    to debug
  * trivial: Show a critical warning rather than crashing
  * fu-debug: Redirect all debugging output to stderr instead of
    stdout
  * trivial: synapticsmst: clarify some error flows
  * synapticsmst: Adjust panamera ESM update routine for some
    reported issues
  * trivial: synapticsmst: downgrade remote control retry statement
    to debug
  * trivial: Update FU_DEVICE_REMOVE_DELAY_USER_REPLUG from 20s to
    40s
  * fu-engine: Optionally wait for replug before updating a device
  * fu-device-list: Use delayed device removal when removing the
    tree
  * thunderbolt: Use replugging from the daemon
  * trivial: device-list: Correct a minor logic error
  * Add support for devices to show an estimated flash time
  * Marked some CL options for translation
  * trivial: uefi: Only set EFI variables on real systems
  * trivial: wacom: correct some errors caught by static analysis
  * trivial: dell: Assert true in self tests
  * trivial: amt: correct a situation that might overwrite error
  * trivial: amt: correct a potential lack of error
  * ci: Run clang static analysis for Ubuntu build rather than just
    clang compiler
  * trivial: standalone: Check argument make sense with command
  * trivial: standalone: If missing flatpak dependencies, download
    them
  * trivial: Fix a tiny memory leak on startup
  * nvme: Initialize the buffer before reading the contents
  * trivial: thunderbolt: don't reuse GError error_local in update
    function
  * trivial: Do not use AsProfile
  * trivial: nvme: Remove quirk for Hynix SSD
  * contrib: Add a standalone installer creation script
  * trivial: fu-util/fu-tool: Move --version into a common shared
    function
  * rts54hid: Add support for Realtek USB devices using vendor HID
    commands
  * fu-engine: Don't show devices pending a reboot in GetUpgrades
  * Add FuMutex helper to make various parts of the daemon
    thread-safe
  * trivial: Return reference counted devices from FuDeviceList
  * rts54hub: Add support for Realtek USB devices using vendor HUB
    commands
  * uefi: Check the amount of free space on the ESP
  * fu-tool: Import debugging options from fu-debug like fu-main
  * trivial: Skip debugging messages for skipped releases
  * dell: Stop showing errors when no dock plugged in
  * trivial: Allow specifying --daemon-verbose to set the log
    handler
  * trivial: Add the components to the daemon store in one
    operation
  * trivial: Only show the number of loaded components at startup
  * trivial: Remove overzealous debugging
  * trivial: Set a log domain for each file
  * trivial: Remove an assert statement from the daemon
  * superio: Set the physical and logical IDs
  * trivial: Use a fixed GUID for superio
  * trivial: snap: fix TLS communications in classic snap
  * trivial: snap: sync up some missing changes in master snap
  * trivial: snap: Correct bash completion path
  * trivial: snap: Install dbus service in classic snap
- Add pkgconfig(xmlb) BuildRequires: New dependency.
* Tue Dec 11 2018 Gary Ching-Pang Lin <glin@suse.com>
- Add pesign-obs-integration to BuildRequires and add fwupd*.efi to
  BRP_PESIGN_FILES to get it signed
- Add LC_IMAGES and use efivar only if %%{with efi_fw_update}
  + Also update the version requirement of efivar
- Disable Redfish and NVME plugins if %%{without efi_fw_update}
  since those two plugins require efivar
- Remove fwup from BuildRequires since fwupdate is already merged
  into fwupd.
* Mon Dec 10 2018 schwab@suse.de
- Use gnu-efi only if %%{with efi_fw_update}, always use pkgconfig(efivar)
- Fix file list
* Thu Dec  6 2018 Gary Ching-Pang Lin <glin@suse.com>
- Amend %%post and %%postun to install/uninstall fwupd*.efi to the
  EFI system partition
  + Also add shim to Requires for fwupdx64.efi
- Mark fwupdate as obsolete
  + fwupdate has been merged into fwupd since fwupd 1.1.0.
* Mon Nov 12 2018 ndas@suse.de
- fwupd is require for thunderbolt firmware update in SLE15-SP1(fate#322681)
* Thu Sep 13 2018 Nico Kruber <nico.kruber@gmail.com>
- Update to version 1.1.2:
  + New Features:
  - Add a new device flag "ignore-validation" that will override checks
  - Add a new plugin to enumerate EC firmware
  - Add a new plugin to update NVMe hardware
  - Add a plugin for updating using the flashrom command line tool
  - Allow the device list to take care of waiting for the device replug
  - Allow updating just one specific device from the command line
  - Allow upgrades using a self-signed fwupd.efi binary
  - Download firmware if the user specifies a URI
  - Include serial number in daemon device output when trusted
  - Notify all plugins of device removals through a new vfunc
  - Use boltd force power API if available
  + Bugfixes:
  - Add an install hook for classic snap
  - Allow forcing installation even if no AC power is applied
  - Allow using --force to ignore version_lowest
  - Always use the same HardwareIDs as Windows
  - Check the device state before assuming a fake DFU runtime
  - Copy over parent GUIDs from other plugin donors
  - Detect location of python3 interpreter
  - Do not add udev devices after a small delay
  - Don't fail to run if compiled without GPG/PKCS7
  - Fix a segfault in fwupdtool caused by cleanup of USB plugins
  - Implement the systemd recommendations for offline updates
  - Improve performance when reading keys from the quirk database
  - Remove children of devices when the parent is removed
  - Rewrite synapticsmst to use modern error handling
  - Rewrite the unifying plugin to use the new daemon-provided functionality
  - Show a time estimate on the progressbar after an update has started
* Mon Sep 10 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for summary. Trim request for comments from
  description.
* Fri Sep  7 2018 Nico Kruber <nico.kruber@gmail.com>
- Update to version 1.1.1:
  + New Features:
  - Add support for the Synaptics Panamera hardware
  - Add validation for Alpine and Titan Ridge
  - Improve the Redfish plugin to actually work with real hardware
  + Bugfixes:
  - Allow different plugins to add the same device
  - Allow flashing unifying devices in recovery mode
  - Allow running synapticsmst on non-Dell hardware
  - Check the ESP for sanity at at startup
  - Do not hold hidraw devices open forever
  - Don't override _FORTIFY_SOURCE when building the EFI binary
  - Don't show passwords in fwupdmgr
  - Fix a potential segfault in smbios data parsing
  - Fix encoding the GUID into the capsule EFI variable
  - Fix various bugs when reading the thunderbolt version number
  - Reboot synapticsmst devices at the end of flash cycle
  - Show status messages when the daemon is initializing
  - Show the correct title when updating devices
  - Show the reasons that plugins are not run on the CLI
  - Use localedir in po/make-images
* Wed Jul 25 2018 tchvatal@suse.com
- Run %%udev_rules_update in post as package install udev rules
* Thu Jul 12 2018 oliver@getspam.de
- Update to version 1.1.0:
  + New Features:
  - Add a initial Redfish support
  - Add a tool to mimic the original fwupdate CLI interface
  - Allow devices to assign a plugin from the quirk subsystem
  - Change the quirk file structure to be more efficient
  - Merge fwupdate functionality into fwupd
  - Run a plugin vfunc before and after all the composite devices are updated
  - Support more Wacom tablets
  + Bugfixes:
  - Add release information for locked devices
  - Allow building with older meson
  - Detect the EFI system partition location at runtime
  - Do not use 8bitdo bootloader commands after a successful flash
  - Enable accesing downloaded files in flatpak and snap
  - Fix a potential buffer overflow when applying a DFU patch
  - Fix downgrading older releases to devices
  - Fix flashing devices that require a manual replug
  - Fix several small memory leaks in various places
  - Fix the retrieval of Redfish version
  - Fix unifying failure to detach when using a slow host controller
  - Set the Wacom device status when erasing and writing firmware
  - Show errors in the CLI if unable to access directory
  - Use the parent device name for Wacom sub-modules
- Removed enable_pkcs7_when_testing_only.patch
* Wed Jul 11 2018 oliver@getspam.de
- Update to version 1.0.8:
  + New Features (including version 1.0.7):
  - Add an plugin to update some future Wacom tablets
  - Add 'fwupdmgr get-topology' to show logical device tree
  - Add support for creating a flatpak
  - Add support for creating a snap
  - Add support for Motorola S-record files
  - Add the Linux Foundation public GPG keys for firmware and metadata
  - Show a translated warning when the server is limiting downloads
  - Add enable-remote and disable-remote commands to fwupdmgr
  - Add fu_plugin_add_compile_version() for libraries to use
  - Allow requiring specific versions of libraries for firmware updates
  - If no remotes are enabled try to enable the LVFS
  - Show a warning with interactive prompt when enabling a remote
  + Bugfixes (including version 1.0.7):
  - Add a firmware diagnostic tool called fwupdtool
  - Adjust all licensing to LGPL 2.1+
  - Allow installing more than one firmware using 'fwupdmgr install'
  - Allow specifying hwids with OR relationships
  - Do not call fu_plugin_init() on blacklisted plugins
  - Do not require libcolorhug to build
  - Fix a crash in libfwupd where no device ID is set
  - Fix a potential DoS in libdfu by limiting holes to 1MiB
  - Fix a segfault that sometimes occurs during cleanup of USB plugins
  - Fix Hardware-ID{0,1,2,12} compatibility with Microsoft
  - Hide devices that aren't updatable by default in fwupdmgr
  - Search all UEFI GUIDs when matching hardware
  - Stop matching Nintendo Switch Pro in the 8bitdo plugin
  - Check that EFI system partition is mounted before update
  - Disable synapticsmst remote control on failure
  - Don't recoldplug thunderbolt to fix a flashing failure
  - Fix SQL error when running 'fwupdmgr clear-offline'
  - Improve the update report message
  - Only enumerate Dell Docks if the type is known
  - Only run certtool if a new enough gnutls is present
  - Prevent a client crash if the daemon somehow sends invalid data
  - Reboot after scheduling using logind not systemd
  - Use the right encoding for the label in make-images
- Added/backported enable_pkcs7_when_testing_only.patch:
  + needed to disable pkcs7 test during build (can be removed for
    fwupd >= 1.0.9)
* Wed Apr  4 2018 dimstar@opensuse.org
- Update hasbang in installed files from /usr/bin/env python3 to
  /usr/bin/python3.
* Tue Apr  3 2018 mpluskal@suse.com
- Update url
- Small packaging cleanup with spec-cleaner
* Fri Mar 23 2018 antoine.belvire@opensuse.org
- Update to version 1.0.6:
  + New Features:
  - Add bash completion for fwupdmgr.
  - Add support for newest Thunderbolt chips.
  - Allow all functions that take device arguments to be
    prompted.
  - Allow devices to use the runtime version when in bootloader
    mode.
  - Allow overriding ESP mount point via conf file.
  - Delete any old fwupdate capsules and efivars when launching
    fwupd.
  - Generate Vala bindings.
  + Bugfixes:
  - Allow ctrl-d out of the prompt for devices.
  - Allow to create package out of provided binary.
  - Correct handling of unknown Thunderbolt devices.
  - Correctly detect new remotes that are manually copied.
  - Fix a crash related to when passing device to downgrade in
    CLI.
  - Fix running the self tests when no fwupd is installed.
  - Fix Unifying signature writing and parsing for Texas
    bootloader.
  - Only send success and failure reports to the server.
  - Use a CNAME to redirect to the correct CDN for metadata.
  - Use a longer timeout when powering back the Thunderbolt
    device.
* Thu Mar 15 2018 fcrozat@suse.com
- Ensure library package has a dependency on main package,
  otherwise it won't be usable.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 1.0.5:
  + New Features:
  - Offer to reboot when processing an offline update.
  - Report the efivar, libsmbios and fwupdate library versions.
  - Report Thunderbolt safe mode and SecureBoot status.
  - Show the user a URL when they report a known problem.
  - Support split cabinet archives as produced by Windows Update.
  + Bugfixes:
  - Be more careful deleting and modifying device history.
  - Clarify which devices don't have upgrades.
  - Ensure the Thunderbolt version is xx.yy.
  - Fix a daemon warning when using fwupdmgr get-results.
  - Fix crasher with MST flashing.
  - Fix DFU detach with newer releases of libusb.
  - Include the device VID and PID when generating the device-id.
  - Set the RemoteId when using GetDetails.
  - Stop matching 8bitdo DS4 controller VID/PID.
  - Use help2man for dfu-tool and drop docbook dependencies.
  - Use ngettext for any strings with plurals.
  - Use the default value if ArchiveSizeMax is unspecified.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 1.0.4:
  + New Features:
  - Add D-Bus methods to get and modify the history information.
  - Allow the user to share firmware update success or failure.
  - Ask the user to refresh metadata when it is very old.
  - Store firmware update success and failure to a local
    database.
  + Bugfixes:
  - Add a device name for locked UEFI devices.
  - Allow each plugin to opt-in to the recoldplug action.
  - Fix firmware downloading using gnome-software.
  - Fix UX capsule reference to the one specified in efivar.
  - Never add two devices to the daemon with the same ID.
  - Rescan supported flags when refreshing metadata.
- Add pkgconfig(json-glib-1.0) BuildRequires: new dependency.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 1.0.3:
  + New Features:
  - Add a new plugin to add support for CSR "Driverless DFU".
  - Add initial SF30/SN30 Pro support.
  - Support AppStream metadata with relative <location> URLs.
  + Bugfixes:
  - Add more metadata to the user-agent string.
  - Block owned Dell TPM updates.
  - Choose the correct component from provides matches using
    requirements.
  - Do not try to parse huge compressed archive files.
  - Fix a double-free bug in the Udev code.
  - Handle Thunderbolt "native" mode.
  - Use the new functionality in libgcab >= 1.0 to avoid writing
    temp files.
* Thu Dec 21 2017 stefan.bruens@rwth-aachen.de
- Unbreak compilation on non-x86, upstream renamed options to disable
  plugins.
* Tue Dec 19 2017 fcrozat@suse.com
- Update to version 1.0.2:
  + Add a plugin for the Nitrokey Storage device
  + Add support for the original AVR DFU protocol
  + Allow different plugins to claim the same device
  + Allow quirks to set common USB properties
  + Move a common plugin functionality out to a new shared object
  + Optionally delay the device removal for better replugging
  + Set environment variables to allow easy per-plugin debugging
  + Use a SHA1 hash for the internal DeviceID
  + Add quirk for AT32UC3B1256 as used in the RubberDucky
  + Disable the dell plugin if libsmbios fails
  + Don't register for USB UDev events to later ignore them
  + Fix a possible buffer overflow when debugging ebitdo devices
  + Fix critical warning when more than one remote fails to load
  + Fix DFU attaching AVR32 devices like the XMEGA
  + Ignore useless Thunderbolt device types
  + Refactor ColorHug into a much more modern plugin
  + Release the Steelseries interface if getting the version failed
  + Remove autoconf-isms from the meson configure options
  + Show a nicer error message if the requirement fails
  + Sort the output of GetUpgrades correctly
- Changes from version 1.0.1:
  + Add support for HWID requirements
  + Add support for programming various AVR32 and XMEGA parts using DFU
  + Add the various DFU quirks for the Jabra Speak devices
  + Allow specifying the output file type for 'dfu-tool read'
  + Move the database of supported devices out into runtime loaded files
  + Support the IHEX record type 0x05
  + Use help2man to generate the man page at build time
  + Use the new quirk infrastructure for version numbers
  + Catch invalid Dell dock component requests
  + Correctly output Intel HEX files with > 16bit offset addresses
  + Do not try to verify the element write if upload is unsupported
  + Fix a double-unref when updating any 8Bitdo device
  + Fix crash when enumerating with Dell dock connected but with no UEFI
  + Fix uploading large firmware files over DFU
  + Format the BCD USB revision numbers correctly
  + Guess the DFU transfer size if it is not specified
  + Include the reset timeout as wValue to fix some DFU bootloaders
  + Make the error message clearer when sans fonts are missing
  + Support devices with truncated DFU interface data
  + Use the correct remote-specified username and passord when using fwupdmgr
  + Use the correct wDetachTimeOut when writing DFU firmware
  + Verify devices with legacy VIDs are actually 8Bitdo controllers
- Add help2man as BuildRequires.
* Thu Dec 14 2017 stefan.bruens@rwth-aachen.de
- Fix dependencies and build options for non-x86 architectures. At
  least FW updates for USB are arch independent, and EFI FW updates
  can also be applied on Aarch64.
* Fri Oct 27 2017 dimstar@opensuse.org
- Update to version 1.0.0:
  * Add the plugin documentation to the main gtk-doc
  * Add a waiting-for-auth daemon state
  * Add fwupd_remote_get_checksum() to use in client programs
  * Generate the LD script from the GObject Introspection data
  * Prevent fwupd from mounting filesystems
  * uefi: Do not use system-specific infomation for PCI devices
  * uefi: Support uploading the firmware splash image
  * dell: only set coldplug delay when we know we need it
  * dell: only run SMI to toggle host MST GPIO on systems with host MST
  * dell: add functionality to blacklist HW with problems
  * dell: only run on intended chassis
  * thunderbolt-power: always run after thunderbolt plugin
  * Allow plugins to depend on each other
  * Add support for SMBIOSv3
  * dell: prefer to use hwids to get DMI keys and DE table
  * debian: remove /etc/fwupd.conf on upgrade
  * unifying: Use fu_plugin_check_supported()
  * Add fu_plugin_check_supported()
  * unifying: Use a device whitelist to avoid breaking devices
  * Fix various printing issues with the progressbar
  * dell: Fix a trivial whitespace issue
  * Do not fail to load the daemon if cached metadata is invalid
  * Do not store the newest release as part of the FuDevice object
  * Add a method to return a list of upgrades for a specific device
  * Move the downgrade calculation to the daemon
  * Make FuDevice derive from FwupdDevice rather than FwupdResult
  * Add a command 'clear-offline' to fwupdmgr
  * Merge releases where multiple remotes provide the same firmware
  * Remove the UniqueID property
  * uefi: Do not set the release version
  * udev: Do not match USB devices, even with a GUID set
  * Use the intel-wmi-thunderbolt kernel module to force power
  * dell: drop thunderbolt force power code
  * unifying: Add hardcoded summaries for peripheral kinds
  * Create CODE_OF_CONDUCT.md
  * Ensure more devices set the device summary
  * Add an 'Summary' property to each device
  * Add a human-readable title for each remote
  * unifying: Disable if the kernel has no CONFIG_HIDRAW support
  * Move deprecated symbols to a new header
  * Introduce an s390x cross compile target to CI
  * Add ModifyRemote as an easy way to enable and disable remotes like the LVFS
  * Do not auto-open all USB devices at startup
  * dfu: Use FuDeviceLocker
  * unifying: Use FuDeviceLocker
  * colorhug: Use FuDeviceLocker
  * ebitdo: Use FuDeviceLocker
  * altos: Use FuDeviceLocker
  * steelseries: Use FuDeviceLocker
  * usb: Use FuDeviceLocker
  * Add FuDeviceLocker to simplify device open/close lifecycles
  * dfu: Remove DEVO support
  * dfu: Remove the now-unused symtab support
  * Remove the ELF support from libdfu and move the code to the altos plugin
  * Use -Werror when building in Travis CI
  * Do not install the libdfu helper library
  * Parse the SMBIOS DMI table directly
  * usb: Disable the fallback USB plugin
  * Test for missing language translations at build time
  * Fix the libdfu self test failure on s390 and ppc64
* Fri Oct 27 2017 dimstar@opensuse.org
- Update to version 0.9.8:
  * Add a command 'clear-offline' to fwupdmgr
  * Do not fail to load the daemon if cached metadata is invalid
  * Fix a crash when using fu_plugin_device_add_delay()
  * Fix the libdfu self test failure on s390 and ppc64
  * Format the BCD USB revision numbers correctly
  * Never fallback to an offline update from client code
  * Prevent fwupd from mounting filesystems
  * dfu: Allow flashing when the target does not specify an
    alt-name
  * dfu: Do not try to verify the element write if upload is
    unsupported
  * dfu: Fix uploading large firmware files
  * dfu: Include the reset timeout as wValue to fix some hardware
  * dfu: Set the vendor ID to the runtime USB VID
  * dfu: Use 0x0101 as an alias for 0x0110
  * thunderbolt: move test for mock environment
    (gh#hughsie/fwupd#280)
  * udev: Do not match USB devices, even with a GUID set
  * uefi: Do not set the release version
  * unifying: Disable if the kernel has no CONFIG_HIDRAW support
* Tue Sep 19 2017 dimstar@opensuse.org
- Update to version 0.9.7:
  + 10 months worth of bugfixing, integrating more vendor specific
    Firmware update paths.
* Thu Mar  2 2017 dimstar@opensuse.org
- Update to version 0.8.1:
  + Delete duplicate translations (gh#hughsie/fwupd#89).
  + Do not hardcode docbook2man path.
  + Fix fwupdmgr timeout with missing pending database.
  + Fix compiler warnings.
  + Fix a crash when enumerating devices on a Dell WLD15.
  + dell: don't initialize libsmbios on unsupported systems.
  + Do not fail to start on Dell hardware.
  + Adjust systemd confinement restrictions.
  + Do not dlclose modules when running under valgrind.
  + Really remove the NoNewPrivileges systemd confinement.
  + Release fwupd 0.8.1.
* Mon Feb 27 2017 mpluskal@suse.com
- Update to version 0.8.0:
  + Show a different error when checking for updates while on
  + battery power (gh#hughsie/fwupd#68).
  + Clarify the test in --help and man page related to offline
  + (gh#hughsie/fwupd#69).
  + libdfu: Use a heuristic for the start address if the firmware
  + has no DfuSe footer.
  + dell: Don't return the address of a stack variable.
  + dell: Fix a possibly-impossible-to-hit buffer overrun.
  + close USB devices before error returns (gh#hughsie/fwupd#73).
  + Make libelf support optional.
  + Always make sure we're getting a C99 compiler.
  + Fix redeclaration of polkit autocleanup functions.
  + Uncomment SystemdService parameter in the dbus service file
  + (gh#hughsie/fwupd#74).
  + Make all providers and plugins share a GUsbContext.
  + Unexport libebitdo.
  + Move the plugins into plugin-specific directories.
  + Convert the providers to plugins to simplify code and for
  + future features.
  + Add support for Logitech Unifying devices.
  + Add a set of vfuncs that are run before and after a device
  + update.
  + Return the pending UEFI update when not on AC power.
  + Move the UPower functionality to a plugin.
  + Fix udev plugin loading.
  + fix dfu plugin loading.
  + Disable PrivateNetwork on systemd service.
  + Use more restrictive settings when running under systemd.
  + dell: add a new method for forcing a controller to flash mode.
  + Add VerifyUpdate to update the device checksums server-side.
  + Move the Option ROM parsing to the Udev plugin.
  + Move the device add delay to shared code.
  + Add initial skeleton for Intel Thunderbolt support.
  + unifying: Use the actual bootloader VID/PIDs when in firmware
  + mode.
  + Allow the metadata to match a version of fwupd and the existing
  + fw version.
  + Add fwupd_result_get_device_version_bootloader().
  + Fix the appstream-glib version guards.
  + dell: Add coldplug methods to let other plugins turn on
  + TBT/GPIO.
  + libdfu: Don't read data from some DfuSe targets.
  + Add the ability to run a prepare->exec->cleanup on coldplug.
  + Allow plugins to request that all plugins re-coldplug.
  + thunderbolt: Detecting new devices and add an actual device to
  + the daemon.
  + Add support for flashing the ChaosKey.
  + thunderbolt: add some guards around empty arrays.
  + dell: Adjust the coldplug preparation and cleanup sequence.
  + dell: Fix possible linker problem.
  + Revert "thunderbolt: add some guards around empty arrays".
  + Add fu_plugin_set_coldplug_delay() to allow hardware to
  + initialize if required.
  + altos: Add error checking when using termios.
  + ebitdo: Subclass FuDevice like the altos plugin.
  + altos: Set the flags in the init_real so they work for the
  + cmdline tool.
  + unifying: Subclass FuDevice like the altos plugin.
  + Include all debug messages when run with --verbose.
  + dell: introduce a standalone (noinst) tool to force mode
  + flashes.
  + Introduce plugin for Synaptics MST hubs.
  + synapticsmst: Add cascade support.
  + Only register the D-Bus service when all devices have been
  + added.
  + synapticsmst: Refactor away the global state.
  + synapticsmst: fix cascade support in the plugin.
  + Updates for thunderbolt plugin.
  + thunderbolt: Add special handling for safe mode on Dell systems
  + (gh#hughsie/fwupd#84).
  + synapticsmst: Iterate all nodes rather than hardcoding to 3.
  + synapticsmst: build GUID using dock type.
  + Add a new function fu_dell_supported to fu-dell-common.
  + synapticsmst: add a test suite.
  + synapticsmst: Fix up some trivial whitespace issues.
  + Fix a refcounting issue in the udev plugin.
- Add rpmlintrc untill security review is resolved
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.5:
  + Clean up PO files
  + Verify devices support updating in mode they are called.
  + Fix an assert when unlocking the dummy ESRT device
  + Don't create the UEFI dummy device if the unlock will happen on
  + next boot
  + dell: Match on TB16 as well
  + Fix a -fstack-protector-strong crash when uploading firmware
  + Enable the stack protection in local builds
  + dell: If running in test suite, don't try to get product ID
  + from sysfs
  + libfdfu: Show a warning when getting the alt-name failed
  + dfu: Fix listing devices using the ST reference bootloader
  + Show the nicely formatted target name for DfuSe devices
  + libdfu: Fix two possible critical warnings for corrupt USB
  + descriptors
  + libdfu: Correctly offset addresses when one zone has multiple
  + sectors
  + libdfu: Do not do GetStatus on dfuse upload
  + libdfu: Fix uploading from DfuSe devices
  + libdfu: Use the device offset when writing DfuSe firmware
  + libdfu: Add DfuAction enumerated value to represent a device
  + action
  + libdfu: Use an animated progress bar when performing DFU
  + operations
  + libdfu: Do not do a zero-byte download when in DfuSe mode
  + libdfu: Fix verification of written DfuSe firmware
  + libdfu: Ensure the device is open before claiming the interface
  + libdfu: Ensure the mode is set correctly when faking a runtime
  + libdfu: Re-get the quirks when the DfuDevice gets a new
  + GUsbDevice
  + libdfu: Add quirks for HydraBus as it does not have a DFU
  + runtime
  + libdfu: Match the device booloader or runtime VID and PID when
  + checking firmware
  + Add a 'replace-data' command to dfu-tool
  + string
  + libdfu: Add dfu_sector_get_zone() to get the continuous memory
  + zone number
  + libdfu: Wait for DNBUSY to be cleared when checking the DfuSe
  + status
  + libdfu: Correctly erase DfuSe devices
  + Enable hardening flags on more binaries
  + libdfu: Correctly set the element address when uploading from
  + DfuSe devices
- Add pkgconfig(gmodule-2.0) BuildRequires: Align with what
  + configure checks for.
- Add pkgconfig(libsmbios_c) BuildRequires: Support dell bios.
  + Unfortunatly, until we have fwup packaged and enabled, this will
  + not work.
- Add disabled pkgconfig(libtbtfwu): For future thunderbolt
  + support.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.4:
  + Add a fallback for older appstream-glib releases
  + Write the ELF files with the correct section type
  + Fix libfwupd self tests when a host-provided fwupd is not
  + available
  + Add dfu_firmware_add_symbol()
  + Add the Altos symbol table to the DfuFirmware
  + Use the symtab to set the VID/PID from Altos IHEX firmware
  + images
  + Show the human-readable version in the 'dfu-tool dump' output
  + Allow specifying the argument to 'dfu-tool set-release' in
  + major.minor format.
  + sections
  + Support writing the IHEX symbol table
  + call
  + Load the symbol table from ELF firmware
  + Load the Altos USB descriptor from ELF files
  + Add DFU_CIPHER_KIND_RSA
  + Fix a possible crash when uploading firmware files using libdfu
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.3:
  + build: Fix gtk-doc build when srcdir != builddir
  + In get-details output, display the blob filename
  + Ensure the update ID is set when getting local firmware details
  + Use a private gnupg key store
  + Add support for installing against multiple devices from a CAB
  + file
  + Use the correct firmware blob when installing a composite
  + device update
  + in get-details output, display update_name rather than Unknown
  + Device
  + statements
  + Don't make failures critical while checking versions or locked
  + state
  + Show a more detailed error when installing firmware on the
  + wildcard
  + Add Dell TPM and TB15/WD15 support via new Dell provider.
  + file
  + Allow blacklisting devices by their GUID
  + header file
  + Add XPS 9250 to Dell TPM modeswitch blacklist
  + Only display flashes left in results output when it gets low.
  + Add a small library for talking with 0bitdo hardware
  + Add another compile warning and fix up any build failures
  + Embed fwupd version in generated libfwupd and libdfu
  + documentation
  + Update fwupdmgr manpage for new commands and arguments
  + build: Fix gtk-doc build when srcdir != builddir
  + online not offline
  + Get the firmware version correctly from 0Bitdo gamepads
  + Switch to the Amazon S3 CDN for firmware metadata
  + Fix writing 8Bitdo device firmware
  + be updated
  + Show the vendor flashing instructions when installing
  + Split out the DFU file formats to separate files
  + Add fwupd_result_remove_device_flag()
  + Add FU_DEVICE_FLAG_NEEDS_BOOTLOADER
  + get-updates output
  + Allow providers to export percentage completion
  + Add fwupd_client_get_status()
  + Handle the 8Bitdo bootloader in a better way
  + Show a progress notification when installing firmware
  + Add fwupd_result_get_unique_id()
  + Use the SHA1 hash of the local file data as the component
  + origin
  + Use the correct define prefix for FwupdDeviceFlags
  + libdfu: Fix hang when parsing corrupt IHEX files
  + Add a set-target-size command to dfu-tool
  + Support the 'DEVO' cipher kind in libdfu
  + Add a set-address command to dfu-util
  + Disable the Dell specific code by default
  + Conditionally enable all providers based upon what's installed
  + Add a summary of providers that are enabled from configure
  + Do not use the deprecated GNOME_COMPILE_WARNINGS
  + Ignore devices that do not add at least one GUID
  + Do not attempt to add DFU devices not in runtime mode
  + Save the unique ID in the pending database
  + libdfu: Add initial ELF reading and writing support
  + Add dfu_firmware_format_from_string()
  + Normalize the DfuFirmwareFormat enums
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.2:
  + Allow devices to have multiple assigned GUIDs
  + Only return updatable devices from GetDevices()
  + Add fu_device_get_alternate()
  + Allow metainfo files to match only specific revisions of
  + devices
  + Re-read flags for a device after a provider's unlock routine is
  + done
  + Test for a locked device when trying to install firmware update
  + Enforce allowing providers to take away flash abilities
  + Support returning multiple GUIDs from GetDetails
  + Add a GetDetailsLocal() method to eventually replace
  + GetDetails()
  + break
  + libdfu: Add DfuVersion enumerated values
  + libdfu: Show the DFU protocol version in 'dfu-tool list'
  + Only claim the DFU interface when required
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.1:
  + Fix libdfu CRC check for big endian architectures
  + Add dfu_image_get_element_default()
  + Fix libdfu CRC check for big endian architectures
  + Fix big endian issues when reading and writing DFU and DfuSe
  + files
  + Remove non-interactive pinentry setting from fu-keyring
  + Set the system's DMI product name as the DisplayName for UEFI
  + Re-order output of get-devices to be easier to read
  + Make the device display name nicer
  + update version
  + Return all update descriptions newer than the installed version
  + Add summary and name field for Rival SteelSeries
  + Fix a critical warning when restarting the daemon
  + Add a 'supported' flag to the FuDevice
  + Add fwupd_client_connect()
  + Add a 'monitor' debugging command for fwupdmgr
  + Add device-added, device-removed and device-changed signals
  + Match the AppStream metadata after a device has been adedd
  + Re-match devices when the AppStream metadata is updated
  + Show 'Unknow Device' in fwupdmgr when a device name is not set
  + Set the device description when parsing local firmware files
  + Add support for a new device field "Flashes Left".
  + src/Makefile.am: reshuffle so enableable bits are only
  + referenced when on
  + Add support for a --force flag to override provider warnings
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.7.0:
  + Use g_usb_context_wait_for_replug()
  + Run vendor plugins as required
  + Add a plugin for SteelSeries hardware
  + Add fwupd_device_flag_to_string()
  + Return the device flags when getting firmware details
  + Show device flags in 'fwupdmgr get-devices'
  + Add fwupd_trust_flag_to_string()
  + Export FwupdUpdateState in libfwupd
  + Export FwupdUpdateFlags in libfwupd
  + Add FwupdResult to libfwupd
  + Add a self test framework for libfwupd
  + Add FwupdClient to libfwupd
  + Use FwupdClient from libfwupd in fwupdmgr
  + Use libfwupd inside the daemon
  + Emit a FwupdClient::changed when the daemon emits this signal
  + Rename some of the new libfwupd API to align with the D-Bus
  + names
  + libdfu: Fix up some NULL/FALSE confusion
  + libfwup: Fix up some NULL/FALSE confusion
  + FwupdClient
  + Allow other checksum kinds in FwupdResult
  + Allow SHA-256 hashes when verifying
  + Show the checksum kind in the fwupdmgr output
  + Add Alienware to the version quirk table
  + Do not use /tmp for downloaded files
  + Add fwupd_result_has_device_flag()
  + Do not return updates that require AC when on battery
  + Connect to UPower at startup
  + Test that GPG key import actually was successful (or didn't
  + change a key already in the keyring)
  + Use g_auto() in FuKeyring
  + Return errors of the correct type when using libfwupd
  + Allow overridding the location of the pending database for
  + test suite
  + Allow overriding the location of the provider offline files for
  + test suite
  + Validate that the dbus system bus is available before running
  + libfwupd tests
  + Update README.md for changes that have happened in the project
  + Add some basic explanation of how to use fwupd with various
  + frontends
  + Split out the libdfu-devel package
  + Revert "Allow overridding the location of the pending database
  + for test suite"
  + Revert "Allow overriding the location of the provider offline
  + files for test suite"
  + Allow the test suite to run in %%check
  + Generate gtk-doc documentation for libfwupd
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.6.3:
  + Require AC power before scheduling some types of firmware
  + update
  + Install the hardcoded firmware AppStream file
  + Correct the BCD version number for DFU 1.1
  + Add an unlock method for devices
  + Add ESRT enable method into UEFI provider.
  + Only read PCI OptionROM firmware when devices are manually
  + unlocked
  + Do not use deprecated API from libappstream-glib
  + Ignore the DFU runtime on the DW1820A
  + Export the attribute and quirk values in libdfu
  + Show ignored DFU devices in dfu-util, but not in fwupd
  + Allow defining update vfuncs with no runtime support
  + Revert "Allow defining update vfuncs with no runtime support"
  + Add a simple plugin infrastructure
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.6.2:
  + Add 'Created' and 'Modified' properties on managed devices
  + Fix get-results for UEFI provider.
  + Support vendor-specific UEFI version encodings
  + Move quirks directly into a single table and file.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 0.6.1:
  + Only dump the profiling data when run with --verbose
  + Always persist ColorHug devices after replug
  + Do not misdetect different ColorHug devices
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.6.0:
  + Add support for updating USB devices with DFU
  + libdfu: Add support for DfuSe firmware
  + libdfu: Generate gtk-doc documentation
  + libdfu: Don't rely on specific hardware to be present
  + libdfu: Move the VID:PID checks from the tool to DfuDevice
  + libdfu: Use a custom error domain
  + Use the same device identification string format as Microsoft
  + libdfu: Fix crash when setting a target size
  + libdfu: Allow setting the alternate settings in DfuSe firmware
  + libdfu: Add a merge command to dfu-tool
  + libdfu: Allow choosing a different alt-setting when downloading
  + libdfu: Fix a crash when setting a NULL image name
  + libdfu: Correctly implement auto-boot in dfu_device_download()
  + libdfu: Check for extra args to dfu-tool convert
  + libdfu: Call the progress callback when doing detach
  + Ignore the DFU device detach:attach when verifying
  + libdfu: Require a --force flag to flash wildcard firmware
  + Use new API available in fwup 0.5
  + libdfu: Make the element address 32 bits in size
  + libdfu: Support the ST-specific bitCanAccelerate
  + libdfu: Only do a Detach notification if we're actually doing
    to do it
  + libdfu: Use the progress bar for all uploads and downloads
  + libdfu: Improve the output of 'dfu-util list'
  + libdfu: Support download and upload to ST DfuSe devices
  + libdfu: Fix multi-interface devices like the Neo Freerunner
  + libdfu: Add a pkgconfig file
  + libdfu: Use signals to propagate device state
  + libdfu: Add a context object to handle device hotplug
  + libdfu: Add an example showing GObject Introspection
  + libdfu: Do not ref DfuDevice in DfuTarget so the auto-close
  + logic works
  + Close DFU devices as soon as possible after the transfer has
    completed
  + Emit the changed signal after doing an update
  + Rescan the DFU device after replug to get the new version
  + libdfu: Add dfu_context_get_device_by_platform_id()
  + libdfu: Add dfu_device_get_runtime_release()
  + libdfu: Add dfu_device_get_display_name()
  + libdfu: Fix self tests after recent API change
  + Split out the DFU provider as a new file
  + libdfu: Copy the platform ID and invalidate the GUsbDevice when
    removed
  + libdfu: Accept multiple spaces after the DfuSe sector name
  + libdfu: Verify the GUsbDevice is set before using it
  + libdfu: Remove the weak pointer when destroying the DfuTarget
  + libdfu: Fix dfu_device_wait_for_replug() so it can work with a
    DfuContext
  + Export the AppStream ID when returning device results
  + Rescan the DFU device after firmware has been updated
  + libdfu: Handle cancellation with ctrl+c in dfu-tool
  + libdfu: Add a quirk to support DFU runtime-less devices
  + libdfu: Add an explicit 'attach' method
  + libdfu: Add dfu_firmware_get_image_by_name()
  + libdfu: Make reading and writing to targets easier to
  + understand
  + Fix compile with --disable-shared
  + libdfu: Display all the files shown with 'dfu-tool dump'
  + libdfu: Fix a few crashers found using afl
  + libdfu: Fix another bug discovered by the fuzzer
  + libdfu: Add commands to encrypt and decrypt firmware images
  + libdfu: Show better device errors
  + libdfu: Add DfuCipher which is a property on a target and a
  + firmware file
  + libdfu: Add support for the draft 'DFU Metadata Table
  + Specification'
  + libdfu: Only enumerate the DfuContext when required
  + libdfu: Fix several reported crashes in the inhex32 import code
  + Release fwupd 0.6.0
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.4:
  + Fix compile error against fwupdate git due to dropped
  + functions.
  + Use strerror() when printing errors from libfwupdate
  + Use new API available in fwup 0.5
  + Release fwupd 0.5.4
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.3:
  + Avoid seeking when reading the file magic during refresh
  + Do not assume that the compressed XML data will be NUL
  + terminated
  + debugging
  + Use the correct user agent string for fwupdmgr
  + Release fwupd 0.5.3
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.2:
  + Ensure D-Bus remote errors are registered at fwupdmgr startup
  + Show the dotted-decimal representation of the UEFI version
  + number
  + require appstream-glib 0.5.1
  + not found
  + When the version is from the 'FW' extension do not cache the
  + device
  + Support cabinet archives files with more than one firmware
  + Add the update description to the GetDetails results
  + Add profiling data to debug slow startup times
  + Fix verify-update to produce components with the correct
  + provide values
  + Clear the in-memory firmware store only after parsing a valid
  + XML file
  + Release fwupd 0.5.2
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.1:
  + Fix the error message when no devices can be updated
  + offline update: Use glib api for for reading symlinks
  + Release fwupd 0.5.1
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.5.0:
  + Do not merge the existing firmware metadata with the submitted
  + files
  + Raise the dep on GLib to support and use g_autoptr()
  + Do not reboot if racing with the PackageKit offline update
  + mechanism
  + Release fwupd 0.5.0
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.6:
  + Install fwupd and fwsignd into /usr/lib/$(triplet)/fwupd
  + instead.
  + Use the new secure metadata URI
  + Update the offline update service to invoke right command
  + Don't apply firmware if something else is processing the
  + offline update
  + Remove fwsignd, we have the LVFS now
  + Depend on appstream-glib >= 0.5.0
  + Add application metadata when getting the updates list
  + Simplify the version properties on devices to avoid complexity
  + and bugs
  + Release fwupd 0.1.6
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.5:
  + Allow fwupd to be autostarted by systemd
  + Sign the test binary with the correct key
  + Do not pre-convert the update description from AppStream XML
  + Devices with option ROM are always internal
  + Prefer the GUID from the firmware than the device
  + Allow no arguments to 'fwupdmgr verify-update' and use sane
  + defaults
  + Add the ability to remove a vendor on the LVFS site
  + Fix validation of written firmware
  + Move the verification and metadata matching phase to the daemon
  + Add a simple config file to store the correct LVFS download URI
  + Make parsing the option ROM runtime optional
  + Add a Raspberry Pi firmware provider
  + Use the AppStream 0.9 firmware specification by default
  + Generate the ColorHug test files at runtime
  + Release fwupd 0.1.5
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.4:
  + man/Makefile.am: Add --sgml to docbook2man invocation
  + Make statements about storing private keys stronger.
  + Provide a way for clients to add new firmware metadata to the
  + system cache
  + Fix fwupd-offline-update.service
  + Revert "man/Makefile.am: Add --sgml to docbook2man invocation"
  + Add a Udev firmware provider
  + Extract the version string from the ROM in PCI devices
  + Add a 'verify' command that verifies the cryptographic hash of
  + device firmware
  + Make the ROM parsing more robust and add self tests
  + Get the version number out from Intel VBIOS too
  + Provide a way to dump the option ROM using the command line
  + build: gusb is required even without colorhug
  + remove unused variables
  + Do not return NULL as a gboolean
  + Fix Intel VBIOS detection on Dell hardware
  + Do not use the subsystem information when constructing the fake
  + GUID
  + Actually parse the PCI option ROM
  + Accept multiple files at one time when using fwupdmgr dump-rom
  + verify run
  + Add a 'verify-update' command to fwupdmgr
  + Fix trivial bug when parsing firmware versions
  + Keep hitting the hardware until it gives us enough ROM
  + Make the version parsing more resilient to corrupt firmware
  + Fix the example .inf file to reflect reality
  + Fix ROM PPID searching to work for all ROMs
  + Move the LVFS website to the fwupd project
  + Add the ability to create detached signatures
  + Allow cab files to be saved
  + Add a simple signing server that operates on .cab files
  + Automatically download metadata using fwupdmgr if required
  + Don't call efibootmgr after fwupdate.
  + Associate the contact email address directly with the vendor
  + key
  + Use the actual LVFS GPG key
  + Allow running fwsignd as the non-root user
  + metadata
  + Do not merge existing LVFS metadata
  + Do not use the file hash when storing the LVFS submitted
  + firmwares
  + Move GetUpdates to the daemon
  + Change the DBus method for installing firmware to 'Install'
  + Allow installing an offline UEFI update without --offline
  + Add a 'fwupdmgr update' command to update all devices to latest
  + versions
  + 'update' command
  + Increase the size limit of firmware to 50Mb
  + Only sign files when the entire file has been copied
  + Fallback to offline install when calling the update argument.
  + Reload appstream data after refreshing.
  + Release fwupd 0.1.4
* Thu Dec 10 2015 dimstar@opensuse.org
- Update to version 0.1.3:
  + Coldplug the devices before acquiring the well known name
  + Add an UNKNOWN status so we can return meaningful enum values
  + Run the offline actions using systemd when required
  + Get the firmware version from the device descriptors
  + Added syntax highlighting
  + More markup
  + Support OpenHardware devices using the fwupd vendor extensions
  + Move boolean properties on the device to a set of flags
  + Release fwupd 0.1.3
* Wed May 27 2015 dimstar@opensuse.org
- Update to version 0.1.2:
  + More markup
  + Fixed typos and markup for executable
  + Add slovak translation
  + Add helper code to validate public key signatures
  + Decompress any firmware signatures in the .cab file
  + Verify firmware if a detached signature is present
  + Show the firmware trust status when doing GetDetails()
  + Only allow signed firmware to be upgraded without a password
  + Add some guidelines for vendors to README
  + Small grammar fix
  + Extract the .cat file alongside the firmware
  + Release fwupd 0.1.2
* Mon Apr 13 2015 dimstar@opensuse.org
- Update to version fwupd_0_1_1:
  + Do not crash when there are no devices to return
  + Add a 'get-updates' command to fwupdmgr
  + Add and document the offline-update lifecycle
  + Create runtime directories if they do not exist
  + Create a libfwupd shared library
  + Export the status as an enumerated value rather than a string
  + Release fwupd 0.1.1
* Mon Apr 13 2015 dimstar@opensuse.org
- Initial package.
